@@ -1,6 +1,6 @@
 # -*- coding: utf8 -*-
 ########################################################################################
-# This file is part of exhale.  Copyright (c) 2017-2021, Stephen McDowell.             #
+# This file is part of exhale.  Copyright (c) 2017-2022, Stephen McDowell.             #
 # Full BSD 3-Clause license available here:                                            #
 #                                                                                      #
 #                https://github.com/svenevs/exhale/blob/master/LICENSE                 #
@@ -555,15 +555,24 @@ def specificationsForKind(kind):
         The correctly formatted specifier(s) for the given ``kind``.  If no specifier(s)
         are necessary or desired, the empty string is returned.
     '''
+    # TODO: this is to support the monkeypatch
+    # https://github.com/svenevs/exhale/issues/27
+    ret = []
+
     # use the custom directives function
     if configs.customSpecificationsMapping:
-        return configs.customSpecificationsMapping[kind]
+        ret = configs.customSpecificationsMapping[kind]
 
     # otherwise, just provide class and struct
     if kind == "class" or kind == "struct":
-        return [":members:", ":protected-members:", ":undoc-members:"]
+        ret = [":members:", ":protected-members:", ":undoc-members:"]
 
-    return []  # use breathe defaults
+    # the monkeypatch re-configures breathe_default_project each time which was
+    # foolishly relied on elsewhere and undoing that blunder requires undoing
+    # all of the shenanigans that is configs.py...
+    if not any(":project:" in spec for spec in ret):
+        ret.insert(0, ":project: " + configs._the_app.config.breathe_default_project)
+    return ret
 
 
 class AnsiColors:
